@@ -2,7 +2,7 @@
 
 -- |
 -- Module      : Criterion.Plot
--- Copyright   : (c) 2009, 2010 Bryan O'Sullivan
+-- Copyright   : (c) 2009, 2010, 2011 Bryan O'Sullivan
 --
 -- License     : BSD-style
 -- Maintainer  : bos@serpentine.com
@@ -20,26 +20,30 @@ module Criterion.Plot
 
 import Control.Monad.Trans (liftIO)
 import Criterion.Config
+import Criterion.IO (printError)
 import Criterion.Monad (Criterion, getConfigItem)
-import qualified Data.Vector.Unboxed as U
 import Data.Char (isSpace, toLower)
 import Data.Foldable (forM_)
 import Data.List (group, intersperse)
-import Statistics.KernelDensity (Points, fromPoints)
 import Statistics.Function (indexed)
+import Statistics.KernelDensity (Points, fromPoints)
 import Statistics.Types (Sample)
 import System.FilePath (pathSeparator)
 import System.IO (IOMode(..), Handle, hPutStr, withBinaryFile)
 import Text.Printf (printf)
 import qualified Criterion.MultiMap as M
-import Criterion.IO (printError)
+import qualified Data.Vector.Unboxed as U
 
 #ifdef HAVE_CHART
+# if MIN_VERSION_base(4,3,0)
+import Control.Monad (void)
+# endif
+
 import Data.Accessor ((^=))
 import Graphics.Rendering.Chart hiding (Plot,c)
-#ifdef HAVE_GTK
+# ifdef HAVE_GTK
 import Graphics.Rendering.Chart.Gtk (renderableToWindow)
-#endif
+# endif
 #endif
 
 plotWith :: Plot -> (PlotOutput -> IO ()) -> Criterion ()
@@ -59,22 +63,22 @@ plotTiming CSV desc times = do
       putRow h [show x, show y]
 
 #ifdef HAVE_CHART
-plotTiming (PDF x y) desc times =
+plotTiming (PDF x y) desc times = void $
   renderableToPDFFile (renderTiming desc times) x y
                       (mangle $ printf "%s timings %dx%d.pdf" desc x y)
 
-plotTiming (PNG x y) desc times =
+plotTiming (PNG x y) desc times = void $
   renderableToPNGFile (renderTiming desc times) x y
                       (mangle $ printf "%s timings %dx%d.png" desc x y)
 
-plotTiming (SVG x y) desc times =
+plotTiming (SVG x y) desc times = void $
   renderableToSVGFile (renderTiming desc times) x y
                       (mangle $ printf "%s timings %dx%d.svg" desc x y)
 
-#ifdef HAVE_GTK
-plotTiming (Window x y) desc times =
+# ifdef HAVE_GTK
+plotTiming (Window x y) desc times = void $
   renderableToWindow (renderTiming desc times) x y
-#endif
+# endif
 #endif
 
 plotTiming output _desc _times =
@@ -96,22 +100,22 @@ plotKDE CSV desc _exs points pdf = do
       putRow h [show x, show y]
 
 #ifdef HAVE_CHART
-plotKDE (PDF x y) desc exs points pdf =
+plotKDE (PDF x y) desc exs points pdf = void $
   renderableToPDFFile (renderKDE desc exs points pdf) x y
                       (mangle $ printf "%s densities %dx%d.pdf" desc x y)
 
-plotKDE (PNG x y) desc exs points pdf =
+plotKDE (PNG x y) desc exs points pdf = void $
   renderableToPNGFile (renderKDE desc exs points pdf) x y
                       (mangle $ printf "%s densities %dx%d.png" desc x y)
 
-plotKDE (SVG x y) desc exs points pdf =
+plotKDE (SVG x y) desc exs points pdf = void $
   renderableToSVGFile (renderKDE desc exs points pdf) x y
                       (mangle $ printf "%s densities %dx%d.svg" desc x y)
 
-#ifdef HAVE_GTK
-plotKDE (Window x y) desc exs points pdf =
+# ifdef HAVE_GTK
+plotKDE (Window x y) desc exs points pdf = void $
     renderableToWindow (renderKDE desc exs points pdf) x y
-#endif
+# endif
 #endif
 
 plotKDE output _desc _exs _points _pdf =
@@ -221,3 +225,8 @@ mangle = concatMap (replace ((==) '-' . head) "-")
        . map (replace isSpace '-' . replace (==pathSeparator) '-' . toLower)
     where replace p r c | p c       = r
                         | otherwise = c
+
+#if defined(HAVE_CHART) && !MIN_VERSION_base(4,3,0)
+void :: (Monad m) => m a -> m ()
+void f = f >> return ()
+#endif
